# $Id$
# Authority: dag

Summary: TCP redirection server
Name: rinetd
Version: 0.62
Release: 1
License: GPL
Group: System Environment/Daemons
URL: http://www.boutell.com/rinetd/

Packager: Dag Wieers <dag@wieers.com>
Vendor: Dag Apt Repository, http://dag.wieers.com/apt/

Source: http://www.boutell.com/rinetd/http/rinetd.tar.gz 
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

Requires: /sbin/chkconfig
Requires: /sbin/service

%description
rinetd is a daemon which redirects TCP connections from one IP address
and port to another IP address and port. This daemon is often used to
access services behind a firewall.

%prep
%setup -n %{name}

%{__cat} <<EOF >rinetd.conf
### Example configuration file for rinetd

### To forward connections to port 80 on 10.10.10.2 to port 80 on 192.168.0.2
#10.10.10.2 80 192.168.0.2 80

### To forward connections to port 80 on all addresses to port 80 on 192.168.0.2
#0.0.0.0 80 192.168.0.2 80

### Access controls can be set with allow and deny rules
### allow and deny before the first forwarding rule are global
### allow and deny after a specific rule apply to it only

### This rule allows hosts from 172.16.32.0/24 netblock
#allow 172.16.32.*

### This rule denies the host 192.168.32.12
#deny 192.168.32.12

### rinetd supports logging - to enable, uncomment the following
#logfile /var/log/rinetd.log

### By default, logs are in a tab-delimited format. Web common-log format
### is available by uncommenting the following
#logcommon
EOF

%{__cat} <<EOF >rinetd.logrotate
/var/log/rinetd.log {
    missingok
    notifempty
    delaycompress
    postrotate
        /sbin/service rinetd restart &>/dev/null || :
    endscript
}
EOF

%{__cat} <<'EOF' >rinetd.init
#!/bin/sh
#
# rinetd A TCP redirection server
#
# chkconfig: - 80 20
# description: rinetd is a TCP redirection server
# processname: rinetd
# config: %{_sysconfdir}/rinetd.conf

# Source function library.
source %{_initrddir}/functions

# Source networking configuration.
source %{_sysconfdir}/sysconfig/network

# Check that networking is up.
[ "$NETWORKING" = "no" ] && exit 0

exec="%{_sbindir}/rinetd"
prog=$(basename $exec)

lockfile="%{_localstatedir}/lock/subsys/$prog"

start() {
    echo -n $"Starting $prog: "
    daemon $exec
    retval=$?
    echo
    [ $retval -eq 0 ] && touch $lockfile
    return $retval
}

stop() {
    echo -n $"Stopping $prog: "
    killproc $prog
    retval=$?
    echo
    [ $retval -eq 0 ] && rm -f $lockfile
    return $retval
}

restart() {
    stop
    start
}

reload() {
    if [ -f "$lockfile" ]; then
        echo -n $"Reloading $prog: "
        killproc $prog -HUP
        retval=$?
        echo
        return $retval
    else
        restart
    fi
}

force_reload() {
    restart
}

status() {
    status $prog
}

case "$1" in
    start|stop|restart|reload)
        $1
        ;;
    force-reload)
        force_reload
        ;;
    status)
        status
        ;;
    condrestart|try-restart)
        [ ! -f $lockfile ] || restart
        ;;
    *)
        echo $"Usage: $0 {start|stop|status|restart|try-restart|reload|force-reload}"
        exit 2
esac
EOF

%build
%{__make} %{?_smpmflags} CFLAGS="%{optflags}"

%install
%{__rm} -rf %{buildroot}
%{__install} -Dp -m0755 rinetd %{buildroot}%{_sbindir}/rinetd
%{__install} -Dp -m0644 rinetd.8 %{buildroot}%{_mandir}/man8/rinetd.8
%{__install} -Dp -m0644 rinetd.conf %{buildroot}%{_sysconfdir}/rinetd.conf
%{__install} -Dp -m0755 rinetd.init %{buildroot}%{_initrddir}/rinetd
%{__install} -Dp -m0644 rinetd.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/rinetd

%clean
%{__rm} -rf %{buildroot}

%post
/sbin/chkconfig --add rinetd

%preun
if [ $1 -eq 0 ]; then
    /sbin/service rinetd stop &>/dev/null || :
    /sbin/chkconfig --del rinetd
fi

%postun
if [ $1 -ge 1 ]; then
    /sbin/service rinetd condrestart &>/dev/null || :
fi

%files
%defattr(-, root, root, 0755)
%doc CHANGES README index.html
%doc %{_mandir}/man8/rinetd.8*
%config(noreplace) %{_sysconfdir}/logrotate.d/rinetd
%config(noreplace) %{_sysconfdir}/rinetd.conf
%config %{_initrddir}/rinetd
%{_sbindir}/rinetd

%changelog
* Mon Nov 19 2007 Dag Wieers <dag@wieers.com> - 0.62-1
- Initial package. (using DAR)
